#-*- coding: utf-8 -*-
#
# Jointure_FILM_liste_de_dictionnaires.py
 
from os import chdir
from os import listdir

# Se déplacer dans le dossier en cours si besoin
path = r'P:\PRO\USB\NSI\NSI DONNEES EN TABLE'
chdir(path)

import csv

from copy import deepcopy

# Fusion, jointure de deux tables qui possèdent un attribut commun : cle_commune
def jointure(table1, table2, cle_commune):
    new_table = []
    for ligne1 in table1:
        for ligne2 in table2:
            if ligne1[cle_commune] == ligne2[cle_commune]:
                new_line = deepcopy(ligne1)
                for cle in ligne2:
                    new_line[cle] = ligne2[cle]
                new_table.append(new_line)
    return new_table


# On créer la liste vide
table_coordonnees=[]
 
# Lecture de la table csv, le résultat est dans une 
# liste de dictionnaires
with open('COORDONNEES.CSV', encoding="utf8") as myFile:
    reader = csv.DictReader(myFile,delimiter=';')
    for row in reader:  
        table_coordonnees.append(row)	

# On créer la liste vide
table_seances=[]
 
# Lecture de la table csv, le résultat est dans une 
# liste de dictionnaires
with open('SEANCES.CSV', encoding="utf8") as myFile:
    reader = csv.DictReader(myFile,delimiter=';')
    for row in reader:  
        table_seances.append(row)	
        
table_jointure = jointure(table_coordonnees,table_seances,'Salle')

print('Table créée par jointure sur les tables Coordonnees Seances avec la clé Salle')
for x in range(len(table_jointure)):
    print(table_jointure[x])    

print()
print() 


# Création d'un fichier .csv résultat de la jointure
nomFichier = "JOINTURE_TABLE_FROM_DICO.csv"

with open(nomFichier,'w',encoding="utf8",newline='') as csvfile:
    writer = csv.DictWriter(csvfile, delimiter=';', \
                            fieldnames=table_jointure[0].keys())
    writer.writeheader()
    for row in table_jointure:
        writer.writerow(row)

# Exploitation de la jointure pour répondre à la question du cours
# Quelles sont les adresses des salles qui projettent des films entre 18H30 et 19H15 ?
# La jointure contient toutes les salles - horaires - adresses il suffit de ne conserver
# que celles qui sont dans l'intervalle 18H30 : 19H15

# Sélection de lignes : intervalle 18H30 : 19H15
liste_lignes = [ x for x in table_jointure if x['Horaire'] >= '18H30' and x['Horaire'] <= '19H15' ]


print('Quelles sont les adresses des salles qui projettent des films entre 18H30 et 19H15 ?')
for x in range(len(liste_lignes)):
    print(liste_lignes[x]['Adresse'])

print()
print() 
    
# Pour éliminer les doublons on utilise un ensemble
# voir ici 
# https://www.fil.univ-lille1.fr/~L1S2API/CoursTP/ensembles_et_dictionnaires.html

# Création de l'ensemble par compréhension
ensemble_lignes = set([ x['Adresse'] for x in table_jointure 
                    if x['Horaire'] >= '18H30' and x['Horaire'] <= '19H15' ] )

# On ne peut pas itérer un ensemble avec un index car il n'y a pas de relation d'ordre
# On test la présence des éléments par in
print('Quelles sont les adresses des salles qui projettent des films entre 18H30 et 19H15 ?')
print('Sans les doublons :')

for x in ensemble_lignes:
    print(x) 
    
           